@@ -3,7 +3,9 @@ from contextvars import (
     ContextVar,
 )
 from typing import (
+    Optional,
     Tuple,
+    TextIO,
 )
 
 # Local libraries
@@ -13,6 +15,8 @@ from tracers.containers import (
 
 LEVEL: ContextVar[int] = \
     ContextVar('LEVEL', default=0)
+LOGGING_TO: ContextVar[Optional[TextIO]] = \
+    ContextVar('LOGGING_TO', default=None)
 STACK: ContextVar[Tuple[Frame, ...]] = \
     ContextVar('STACK', default=())
 TRACING: ContextVar[bool] = \
